==> nb_utils-3.2.11%2B4.tar.gz: lib/nb_utils.dart <==
library nb_utils;

import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:nb_utils/src/colors.dart';
import 'package:nb_utils/src/device_extensions.dart';

export 'package:connectivity/connectivity.dart';
export 'package:fluttertoast/fluttertoast.dart';
export 'package:shared_preferences/shared_preferences.dart';

export 'src/Marquee.dart';
export 'src/colors.dart';
export 'src/constants.dart';
export 'src/context_extensions.dart';
export 'src/date_time_utils.dart';
export 'src/decorations.dart';
export 'src/device_extensions.dart';
export 'src/extensions.dart';
export 'src/livestream.dart';
export 'src/network_utils.dart';
export 'src/number_extensions.dart';
export 'src/scroll_extensions.dart';
export 'src/shared_pref.dart';
export 'src/string_extensions.dart';
export 'src/text_extensions.dart';
export 'src/time_formatter.dart';
export 'src/widget_extensions.dart';
export 'src/widgets.dart';
export 'src/widgets/responsive.dart';
export 'src/widgets/ul.dart';
export 'src/widgets/loader.dart';

//region Global variables - This variables can be changed.
Color textPrimaryColorGlobal = textPrimaryColor;
Color textSecondaryColorGlobal = textSecondaryColor;
Color shadowColorGlobal = Colors.black12;
Color appBarBackgroundColorGlobal = Colors.white;

double defaultRadius = 8.0;
double defaultBlurRadius = 5.0;
double defaultSpreadRadius = 2.0;
double defaultAppBarElevation = 4.0;

double textBoldSizeGlobal = 16;
double textPrimarySizeGlobal = 16;
double textSecondarySizeGlobal = 14;

double tabletBreakpointGlobal = 720.0;
double desktopBreakpointGlobal = 1200.0;

String fontFamilyBoldGlobal;
String fontFamilyPrimaryGlobal;
String fontFamilySecondaryGlobal;
//endregion

/// Go back to previous screen.
void finish(context, [Object result]) => Navigator.pop(context, result);

/// Go to new screen with provided screen tag.
///
/// ```dart
/// launchNewScreen(context, '/HomePage');
/// ```
launchNewScreen(context, String tag) => Navigator.of(context).pushNamed(tag);

/// Removes all previous screens from the back stack and redirect to new screen with provided screen tag
///
/// ```dart
/// launchNewScreenWithNewTask(context, '/HomePage');
/// ```
launchNewScreenWithNewTask(context, String tag) =>
    Navigator.of(context).pushNamedAndRemoveUntil(tag, (r) => false);

/// Returns Color from hex String.
///
/// ```dart
/// Color color = getColorFromHex('#E5E5E5');
///
/// returns default color if not able to parse given hex
/// ```
Color getColorFromHex(String hexColor, {Color defaultColor}) {
  try {
    if (!hexColor.startsWith('#')) {
      hexColor = '#$hexColor';
    }
    return Color(int.parse(hexColor.substring(1, 7), radix: 16) + 0xFF000000);
  } catch (e) {
    if (defaultColor != null) {
      return defaultColor;
    } else {
      throw ArgumentError('Can not parse provided hex $hexColor');
    }
  }
}

/// Hide soft keyboard
hideKeyboard(context) => FocusScope.of(context).requestFocus(FocusNode());

/// Callback after build widget is rendered
mixin AfterLayoutMixin<T extends StatefulWidget> on State<T> {
  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance
        .addPostFrameCallback((_) => afterFirstLayout(context));
  }

  void afterFirstLayout(BuildContext context);

  @override
  void dispose() {
    super.dispose();
  }
}

/// Styles

// Bold Text Style
TextStyle boldTextStyle({
  int size,
  Color color,
  FontWeight weight = FontWeight.bold,
  String fontFamily,
  double letterSpacing,
  FontStyle fontStyle,
  double wordSpacing,
  TextDecoration decoration,
  TextDecorationStyle textDecorationStyle,
  TextBaseline textBaseline,
  Color decorationColor,
}) {
  return TextStyle(
    fontSize: size != null ? size.toDouble() : textBoldSizeGlobal,
    color: color ?? textPrimaryColorGlobal,
    fontWeight: weight,
    fontFamily: fontFamily ?? fontFamilyBoldGlobal,
    letterSpacing: letterSpacing,
    fontStyle: fontStyle,
    decoration: decoration,
    decorationStyle: textDecorationStyle,
    decorationColor: decorationColor,
    wordSpacing: wordSpacing,
    textBaseline: textBaseline,
  );
}

// Primary Text Style
TextStyle primaryTextStyle({
  int size,
  Color color,
  FontWeight weight = FontWeight.normal,
  String fontFamily,
  double letterSpacing,
  FontStyle fontStyle,
  double wordSpacing,
  TextDecoration decoration,
  TextDecorationStyle textDecorationStyle,
  TextBaseline textBaseline,
  Color decorationColor,
}) {
  return TextStyle(
    fontSize: size != null ? size.toDouble() : textPrimarySizeGlobal,
    color: color ?? textPrimaryColorGlobal,
    fontWeight: weight,
    fontFamily: fontFamily ?? fontFamilyPrimaryGlobal,
    letterSpacing: letterSpacing,
    fontStyle: fontStyle,
    decoration: decoration,
    decorationStyle: textDecorationStyle,
    decorationColor: decorationColor,
    wordSpacing: wordSpacing,
    textBaseline: textBaseline,
  );
}

// Secondary Text Style
TextStyle secondaryTextStyle({
  int size,
  Color color,
  FontWeight weight = FontWeight.normal,
  String fontFamily,
  double letterSpacing,
  FontStyle fontStyle,
  double wordSpacing,
  TextDecoration decoration,
  TextDecorationStyle textDecorationStyle,
  TextBaseline textBaseline,
  Color decorationColor,
}) {
  return TextStyle(
    fontSize: size != null ? size.toDouble() : textSecondarySizeGlobal,
    color: color ?? textSecondaryColorGlobal,
    fontWeight: weight,
    fontFamily: fontFamily ?? fontFamilySecondaryGlobal,
    letterSpacing: letterSpacing,
    fontStyle: fontStyle,
    decoration: decoration,
    decorationStyle: textDecorationStyle,
    decorationColor: decorationColor,
    wordSpacing: wordSpacing,
    textBaseline: textBaseline,
  );
}

// Create Rich Text
RichText createRichText(
  List<TextSpan> list, {
  TextOverflow overflow = TextOverflow.ellipsis,
  int maxLines,
  TextAlign textAlign = TextAlign.left,
}) {
  return RichText(
    text: TextSpan(children: list),
    overflow: overflow,
    maxLines: maxLines,
    textAlign: textAlign,
  );
}

/// Toast for default time
void toast(
  String value, {
  ToastGravity gravity = ToastGravity.BOTTOM,
  length = Toast.LENGTH_SHORT,
  Color bgColor,
  Color textColor,
}) {
  Fluttertoast.showToast(
    msg: value,
    gravity: gravity,
    toastLength: length,
    backgroundColor: bgColor,
    textColor: textColor,
  );
}

/// Toast for long period of time
void toastLong(
  String value, {
  ToastGravity gravity = ToastGravity.BOTTOM,
  length = Toast.LENGTH_LONG,
  Color bgColor,
  Color textColor,
}) {
  toast(
    value,
    gravity: gravity,
    bgColor: bgColor,
    textColor: textColor,
    length: length,
  );
}

/// Prints only if in debug or profile mode
void log(Object value) {
  if (!kReleaseMode) print(value);
}

/// Returns MaterialColor from Color
MaterialColor createMaterialColor(Color color) {
  List strengths = <double>[.05];
  Map swatch = <int, Color>{};
  final int r = color.red, g = color.green, b = color.blue;

  for (int i = 1; i < 10; i++) {
    strengths.add(0.1 * i);
  }
  strengths.forEach((strength) {
    final double ds = 0.5 - strength;
    swatch[(strength * 1000).round()] = Color.fromRGBO(
      r + ((ds < 0 ? r : (255 - r)) * ds).round(),
      g + ((ds < 0 ? g : (255 - g)) * ds).round(),
      b + ((ds < 0 ? b : (255 - b)) * ds).round(),
      1,
    );
  });
  return MaterialColor(color.value, swatch);
}

/// Change status bar Color and Brightness
void setStatusBarColor(
  Color statusBarColor, {
  Color systemNavigationBarColor,
  Brightness statusBarBrightness,
  Brightness statusBarIconBrightness,
}) {
  SystemChrome.setSystemUIOverlayStyle(
    SystemUiOverlayStyle(
      statusBarColor: statusBarColor,
      systemNavigationBarColor: systemNavigationBarColor,
      statusBarBrightness: statusBarBrightness,
      statusBarIconBrightness: statusBarIconBrightness,
    ),
  );
}

/// Set orientation to portrait
void setOrientationPortrait() {
  SystemChrome.setPreferredOrientations([
    DeviceOrientation.portraitDown,
    DeviceOrientation.portraitUp,
  ]);
}

/// Set orientation to landscape
void setOrientationLandscape() {
  SystemChrome.setPreferredOrientations([
    DeviceOrientation.landscapeRight,
    DeviceOrientation.landscapeLeft,
  ]);
}

/// Returns current PlatformName
String platformName() {
  if (isLinux) return 'Linux';
  if (isWeb) return 'Web';
  if (isMacOS) return 'macOS';
  if (isWindows) return 'Windows';
  if (isAndroid) return 'Android';
  if (isIos) return 'iOS';
  return '';
}

/// Custom scroll behaviour
Function(BuildContext, Widget) scrollBehaviour() {
  return (context, child) =>
      ScrollConfiguration(behavior: SBehavior(), child: child);
}

/// Custom scroll behaviour widget
class SBehavior extends ScrollBehavior {
  @override
  Widget buildViewportChrome(
          BuildContext context, Widget child, AxisDirection axisDirection) =>
      child;
}

/// Invoke Native method and get result
Future<T> invokeNativeMethod<T>(String channel, String method,
    [dynamic arguments]) async {
  var platform = MethodChannel(channel);
  return await platform.invokeMethod<T>(method, arguments);
}

==> nb_utils-3.3.0%2B4.tar.gz: lib/nb_utils.dart <==
library nb_utils;

import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:nb_utils/src/colors.dart';
import 'package:nb_utils/src/device_extensions.dart';
import 'package:nb_utils/src/shared_pref.dart';
import 'package:shared_preferences/shared_preferences.dart';

export 'package:connectivity/connectivity.dart';
export 'package:fluttertoast/fluttertoast.dart';
export 'package:shared_preferences/shared_preferences.dart';

export 'src/AppButton.dart';
export 'src/AppTextField.dart';
export 'src/Marquee.dart';
export 'src/colors.dart';
export 'src/constants.dart';
export 'src/context_extensions.dart';
export 'src/date_time_utils.dart';
export 'src/decorations.dart';
export 'src/device_extensions.dart';
export 'src/extensions.dart';
export 'src/livestream.dart';
export 'src/network_utils.dart';
export 'src/scroll_extensions.dart';
export 'src/shared_pref.dart';
export 'src/string_extensions.dart';
export 'src/text_extensions.dart';
export 'src/time_formatter.dart';
export 'src/widget_extensions.dart';
export 'src/widgets.dart';
export 'src/widgets/DotIndicator.dart';
export 'src/widgets/SettingItemWidget.dart';
export 'src/widgets/loader.dart';
export 'src/widgets/responsive.dart';
export 'src/widgets/ul.dart';

//region Global variables - This variables can be changed.
Color textPrimaryColorGlobal = textPrimaryColor;
Color textSecondaryColorGlobal = textSecondaryColor;
Color shadowColorGlobal = Colors.black12;
Color appBarBackgroundColorGlobal = Colors.white;
Color loaderBgColorGlobal = Colors.white;

double defaultRadius = 8.0;
double defaultAppButtonRadius = 8.0;
double defaultBlurRadius = 5.0;
double defaultSpreadRadius = 2.0;
double defaultAppBarElevation = 4.0;

double textBoldSizeGlobal = 16;
double textPrimarySizeGlobal = 16;
double textSecondarySizeGlobal = 14;

double tabletBreakpointGlobal = 720.0;
double desktopBreakpointGlobal = 1200.0;

String fontFamilyBoldGlobal;
String fontFamilyPrimaryGlobal;
String fontFamilySecondaryGlobal;

int passwordLengthGlobal = 6;

SharedPreferences sharedPreferences;

//endregion

Future<void> initialize() async {
  sharedPreferences = await getSharedPref();
}

/// Go back to previous screen.
void finish(context, [Object result]) => Navigator.pop(context, result);

/// Go to new screen with provided screen tag.
///
/// ```dart
/// launchNewScreen(context, '/HomePage');
/// ```
launchNewScreen(context, String tag) => Navigator.of(context).pushNamed(tag);

/// Removes all previous screens from the back stack and redirect to new screen with provided screen tag
///
/// ```dart
/// launchNewScreenWithNewTask(context, '/HomePage');
/// ```
launchNewScreenWithNewTask(context, String tag) => Navigator.of(context).pushNamedAndRemoveUntil(tag, (r) => false);

/// Returns Color from hex String.
///
/// ```dart
/// Color color = getColorFromHex('#E5E5E5');
///
/// returns default color if not able to parse given hex
/// ```
Color getColorFromHex(String hexColor, {Color defaultColor}) {
  try {
    hexColor = hexColor.toUpperCase().replaceAll("#", "");
    if (hexColor.length == 6) {
      hexColor = "FF" + hexColor;
    }
    return Color(int.parse(hexColor, radix: 16));
  } catch (e) {
    if (defaultColor != null) {
      return defaultColor;
    } else {
      throw ArgumentError('Can not parse provided hex $hexColor');
    }
  }
}

/// Hide soft keyboard
hideKeyboard(context) => FocusScope.of(context).requestFocus(FocusNode());

/// Callback after build widget is rendered
mixin AfterLayoutMixin<T extends StatefulWidget> on State<T> {
  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance.addPostFrameCallback((_) => afterFirstLayout(context));
  }

  void afterFirstLayout(BuildContext context);

  @override
  void dispose() {
    super.dispose();
  }
}

/// Styles

// Bold Text Style
TextStyle boldTextStyle({
  int size,
  Color color,
  FontWeight weight = FontWeight.bold,
  String fontFamily,
  double letterSpacing,
  FontStyle fontStyle,
  double wordSpacing,
  TextDecoration decoration,
  TextDecorationStyle textDecorationStyle,
  TextBaseline textBaseline,
  Color decorationColor,
}) {
  return TextStyle(
    fontSize: size != null ? size.toDouble() : textBoldSizeGlobal,
    color: color ?? textPrimaryColorGlobal,
    fontWeight: weight,
    fontFamily: fontFamily ?? fontFamilyBoldGlobal,
    letterSpacing: letterSpacing,
    fontStyle: fontStyle,
    decoration: decoration,
    decorationStyle: textDecorationStyle,
    decorationColor: decorationColor,
    wordSpacing: wordSpacing,
    textBaseline: textBaseline,
  );
}

// Primary Text Style
TextStyle primaryTextStyle({
  int size,
  Color color,
  FontWeight weight = FontWeight.normal,
  String fontFamily,
  double letterSpacing,
  FontStyle fontStyle,
  double wordSpacing,
  TextDecoration decoration,
  TextDecorationStyle textDecorationStyle,
  TextBaseline textBaseline,
  Color decorationColor,
}) {
  return TextStyle(
    fontSize: size != null ? size.toDouble() : textPrimarySizeGlobal,
    color: color ?? textPrimaryColorGlobal,
    fontWeight: weight,
    fontFamily: fontFamily ?? fontFamilyPrimaryGlobal,
    letterSpacing: letterSpacing,
    fontStyle: fontStyle,
    decoration: decoration,
    decorationStyle: textDecorationStyle,
    decorationColor: decorationColor,
    wordSpacing: wordSpacing,
    textBaseline: textBaseline,
  );
}

// Secondary Text Style
TextStyle secondaryTextStyle({
  int size,
  Color color,
  FontWeight weight = FontWeight.normal,
  String fontFamily,
  double letterSpacing,
  FontStyle fontStyle,
  double wordSpacing,
  TextDecoration decoration,
  TextDecorationStyle textDecorationStyle,
  TextBaseline textBaseline,
  Color decorationColor,
}) {
  return TextStyle(
    fontSize: size != null ? size.toDouble() : textSecondarySizeGlobal,
    color: color ?? textSecondaryColorGlobal,
    fontWeight: weight,
    fontFamily: fontFamily ?? fontFamilySecondaryGlobal,
    letterSpacing: letterSpacing,
    fontStyle: fontStyle,
    decoration: decoration,
    decorationStyle: textDecorationStyle,
    decorationColor: decorationColor,
    wordSpacing: wordSpacing,
    textBaseline: textBaseline,
  );
}

// Create Rich Text
RichText createRichText(
  List<TextSpan> list, {
  TextOverflow overflow = TextOverflow.ellipsis,
  int maxLines,
  TextAlign textAlign = TextAlign.left,
}) {
  return RichText(
    text: TextSpan(children: list),
    overflow: overflow,
    maxLines: maxLines,
    textAlign: textAlign,
  );
}

/// Toast for default time
void toast(
  String value, {
  ToastGravity gravity = ToastGravity.BOTTOM,
  length = Toast.LENGTH_SHORT,
  Color bgColor,
  Color textColor,
}) {
  try {
    Fluttertoast.showToast(
      msg: value,
      gravity: gravity,
      toastLength: length,
      backgroundColor: bgColor,
      textColor: textColor,
    );
  } on PlatformException catch (e) {
    log('PlatformException: $value');
  }
}

/// Toast for long period of time
void toastLong(
  String value, {
  ToastGravity gravity = ToastGravity.BOTTOM,
  length = Toast.LENGTH_LONG,
  Color bgColor,
  Color textColor,
}) {
  toast(
    value,
    gravity: gravity,
    bgColor: bgColor,
    textColor: textColor,
    length: length,
  );
}

/// Prints only if in debug or profile mode
void log(Object value) {
  if (!kReleaseMode) print(value);
}

/// Returns MaterialColor from Color
MaterialColor createMaterialColor(Color color) {
  List strengths = <double>[.05];
  Map swatch = <int, Color>{};
  final int r = color.red, g = color.green, b = color.blue;

  for (int i = 1; i < 10; i++) {
    strengths.add(0.1 * i);
  }
  strengths.forEach((strength) {
    final double ds = 0.5 - strength;
    swatch[(strength * 1000).round()] = Color.fromRGBO(
      r + ((ds < 0 ? r : (255 - r)) * ds).round(),
      g + ((ds < 0 ? g : (255 - g)) * ds).round(),
      b + ((ds < 0 ? b : (255 - b)) * ds).round(),
      1,
    );
  });
  return MaterialColor(color.value, swatch);
}

/// Change status bar Color and Brightness
void setStatusBarColor(
  Color statusBarColor, {
  Color systemNavigationBarColor,
  Brightness statusBarBrightness,
  Brightness statusBarIconBrightness,
}) {
  SystemChrome.setSystemUIOverlayStyle(
    SystemUiOverlayStyle(
      statusBarColor: statusBarColor,
      systemNavigationBarColor: systemNavigationBarColor,
      statusBarBrightness: statusBarBrightness,
      statusBarIconBrightness: statusBarIconBrightness,
    ),
  );
}

/// Set orientation to portrait
void setOrientationPortrait() {
  SystemChrome.setPreferredOrientations([
    DeviceOrientation.portraitDown,
    DeviceOrientation.portraitUp,
  ]);
}

/// Set orientation to landscape
void setOrientationLandscape() {
  SystemChrome.setPreferredOrientations([
    DeviceOrientation.landscapeRight,
    DeviceOrientation.landscapeLeft,
  ]);
}

/// Returns current PlatformName
String platformName() {
  if (isLinux) return 'Linux';
  if (isWeb) return 'Web';
  if (isMacOS) return 'macOS';
  if (isWindows) return 'Windows';
  if (isAndroid) return 'Android';
  if (isIos) return 'iOS';
  return '';
}

/// Custom scroll behaviour
Function(BuildContext, Widget) scrollBehaviour() {
  return (context, child) => ScrollConfiguration(behavior: SBehavior(), child: child);
}

/// Custom scroll behaviour widget
class SBehavior extends ScrollBehavior {
  @override
  Widget buildViewportChrome(BuildContext context, Widget child, AxisDirection axisDirection) => child;
}

/// Invoke Native method and get result
Future<T> invokeNativeMethod<T>(String channel, String method, [dynamic arguments]) async {
  var platform = MethodChannel(channel);
  return await platform.invokeMethod<T>(method, arguments);
}
